@@ -1,4 +1,7 @@
 package Gapp::ButtonBox;
+{
+  $Gapp::ButtonBox::VERSION = '0.480';
+}
 
 use Moose;
 use MooseX::SemiAffordanceAccessor;
@@ -9,7 +12,7 @@ use Gapp::Types qw( GappWidget GappActionOrArrayRef );
 
 extends 'Gapp::Container';
 
-has '+class' => (
+has '+gclass' => (
     default => 'Gtk2::ButtonBox',
 );
 
@@ -18,8 +21,20 @@ has 'buttons' => (
     isa => 'Maybe[ArrayRef]',
 );
 
+sub BUILDARGS {
+    my $class = shift;
+    my %args = @_ == 1 && is_HashRef( $_[0] ) ? %{$_[0]} : @_;
+    
+    # headers visible
+    for my $att ( qw(layout_style) ) {
+        $args{properties}{$att} = delete $args{$att} if exists $args{$att};
+    }
+    
+    __PACKAGE__->SUPER::BUILDARGS( %args );
+}
 
-before '_construct_gtk_widget' => sub {
+
+before '_construct_gobject' => sub {
     my ( $self ) = @_;
     
     if ( $self->buttons && ! @{ $self->content } ) {
@@ -70,13 +85,33 @@ Gapp::ButtonBox - ButtonBox widget
 
 =back
 
+=head1 PROVIDED ATTRIBUTES
+
+=over 4
+
+=item B<buttons>
+
+=over 4
+
+=item is rw
+
+=item isa ArrayRef[Gapp::Action|Gapp::Button].
+
+=back
+
+An C<ArrayRef> of buttons or actions to add to the button box. You may still
+add buttons using the C<content> attribute, however using the C<buttons> attribute
+allows you to use actions.
+
+=back
+
 =head1 AUTHORS
 
 Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
 
 =head1 COPYRIGHT & LICENSE
 
-    Copyright (c) 2011 Jeffrey Ray Hallock.
+    Copyright (c) 2011-2012 Jeffrey Ray Hallock.
 
     This program is free software; you can redistribute it and/or
     modify it under the same terms as Perl itself.
