@@ -1,10 +1,13 @@
 package Gapp::MenuBar;
+{
+  $Gapp::MenuBar::VERSION = '0.480';
+}
 
 use Moose;
 use MooseX::SemiAffordanceAccessor;
 extends 'Gapp::MenuShell';
 
-has '+class' => (
+has '+gclass' => (
     default => 'Gtk2::MenuBar',
 );
 
@@ -25,13 +28,15 @@ Gapp::MenuBar - MenuBar Widget
 
 =over 4
 
-=item L<Gapp::Widget>
+=item L<Gapp::Object>
 
-=item +-- L<Gapp::Container>
+=item +-- L<Gapp::Widget>
 
-=item ....+-- L<Gapp::MenuShell>
+=item ....+-- L<Gapp::Container>
 
-=item ........+-- L<Gapp::MenuBar>
+=item ........+-- L<Gapp::MenuShell>
+
+=item ............+-- L<Gapp::MenuBar>
 
 =back
 
@@ -41,7 +46,7 @@ Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
 
 =head1 COPYRIGHT & LICENSE
 
-    Copyright (c) 2011 Jeffrey Ray Hallock.
+    Copyright (c) 2011-2012 Jeffrey Ray Hallock.
 
     This program is free software; you can redistribute it and/or
     modify it under the same terms as Perl itself.
