@@ -1,6 +1,6 @@
 package Gapp::Meta::Widget::Native::Trait::AssistantPage;
 {
-  $Gapp::Meta::Widget::Native::Trait::AssistantPage::VERSION = '0.47.7';
+  $Gapp::Meta::Widget::Native::Trait::AssistantPage::VERSION = '0.480';
 }
 
 use Moose::Role;
@@ -8,12 +8,6 @@ use MooseX::SemiAffordanceAccessor;
 use MooseX::LazyRequire;
 
 
-has 'page_name' => (
-    is => 'rw',
-    isa => 'Str',
-    default => '',
-);
-
 has 'page_title' => (
     is => 'rw',
     isa => 'Str',
@@ -66,7 +60,7 @@ sub validate {
 
 package Gapp::Meta::Widget::Custom::Trait::AssistantPage;
 {
-  $Gapp::Meta::Widget::Custom::Trait::AssistantPage::VERSION = '0.47.7';
+  $Gapp::Meta::Widget::Custom::Trait::AssistantPage::VERSION = '0.480';
 }
 sub register_implementation { 'Gapp::Meta::Widget::Native::Trait::AssistantPage' };
 
