@@ -1,23 +1,18 @@
 package Gapp::StatusIcon;
+{
+  $Gapp::StatusIcon::VERSION = '0.480';
+}
 
 use Moose;
 use MooseX::SemiAffordanceAccessor;
 
-use Gapp::Types qw( GappActionOrArrayRef );
-use MooseX::Types::Moose qw( Undef );
 
 extends 'Gapp::Widget';
 
-has '+class' => (
+has '+gclass' => (
     default => 'Gtk2::StatusIcon',
 );
 
-#has 'action' => (
-#    is => 'rw',
-#    isa => GappActionOrArrayRef|Undef,
-#);
-
-
 sub BUILDARGS {
     my $class = shift;
     my %args = @_ == 1 && is_HashRef( $_[0] ) ? %{$_[0]} : @_;
@@ -43,12 +38,17 @@ __END__
 
 =head1 NAME
 
-Gapp::StatusIcon - Box widget
+Gapp::StatusIcon - StatusIcon Widget
 
 =head1 OBJECT HIERARCHY
 
-    Gapp::Widget
-    +--Gapp::StatusIcon
+=item L<Gapp::Object>
+
+=item +-- L<Gapp::Widget>
+
+=item ....+-- L<Gapp::StatusIcon>
+
+=head1 DELEGATED
 
 =head1 AUTHORS
 
@@ -56,7 +56,7 @@ Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
 
 =head1 COPYRIGHT & LICENSE
 
-    Copyright (c) 2011 Jeffrey Ray Hallock.
+    Copyright (c) 2011-2012 Jeffrey Ray Hallock.
 
     This program is free software; you can redistribute it and/or
     modify it under the same terms as Perl itself.
