@@ -1,15 +1,26 @@
 package Gapp::TextView;
+{
+  $Gapp::TextView::VERSION = '0.480';
+}
 
 use Moose;
 use MooseX::SemiAffordanceAccessor;
 
-extends 'Gapp::Widget';
-with 'Gapp::Meta::Widget::Native::Trait::FormField';
 
-has '+class' => (
+extends 'Gapp::Widget';
+with 'Gapp::Meta::Widget::Native::Role::FormField';
+
+use Gapp::TextBuffer;
+
+has '+gclass' => (
     default => 'Gtk2::TextView',
 );
 
+has 'buffer' => (
+    is => 'rw',
+    isa => 'Maybe[Gapp::TextBuffer]',
+);
+
 has 'get_hidden_chars' => (
     is => 'rw',
     isa => 'Bool',
@@ -19,13 +30,13 @@ has 'get_hidden_chars' => (
 # returns the value of the widget
 sub get_field_value {
     my ( $self ) = @_;
-    my $buffer = $self->gtk_widget->get_buffer;
+    my $buffer = $self->gobject->get_buffer;
     $buffer->get_text( $buffer->get_start_iter, $buffer->get_end_iter, $self->get_hidden_chars );
 }
 
 sub set_field_value {
     my ( $self, $value ) = @_;
-    my $buffer = $self->gtk_widget->get_buffer;
+    my $buffer = $self->gobject->get_buffer;
     $buffer->set_text( defined $value ? $value : '' );
 }
 
@@ -42,7 +53,7 @@ sub stash_to_widget {
 sub _connect_changed_handler {
     my ( $self ) = @_;
 
-    $self->gtk_widget->get_buffer->signal_connect (
+    $self->gobject->get_buffer->signal_connect (
       changed => sub { $self->_widget_value_changed },
     );
 }
@@ -62,9 +73,11 @@ Gapp::TextView - TextView Widget
 
 =over 4
 
-=item L<Gapp::Widget>
+=item L<Gapp::Object>
 
-=item +-- L<Gapp::TextView>
+=item +-- L<Gapp::Widget>
+
+=item ....+-- L<Gapp::TextView>
 
 =back
 
@@ -72,7 +85,26 @@ Gapp::TextView - TextView Widget
 
 =over 4
 
-=item L<Gapp::Meta::Widget::Native::Trait::FormField>
+=item L<Gapp::Meta::Widget::Native::Role::FormField>
+
+=back
+
+
+=head1 PROVIDED ATTRIBUTES
+
+=over 4
+
+=item B<buffer>
+
+=over 4
+
+=item isa: Gapp::TextBuffer|Undef
+
+=item default: undef
+
+=back
+
+Assigned to the TextView upon construction.
 
 =back
 
@@ -82,7 +114,7 @@ Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
 
 =head1 COPYRIGHT & LICENSE
 
-    Copyright (c) 2011 Jeffrey Ray Hallock.
+    Copyright (c) 2011-2012 Jeffrey Ray Hallock.
 
     This program is free software; you can redistribute it and/or
     modify it under the same terms as Perl itself.
