@@ -1,4 +1,7 @@
 package Gapp::TimeEntry;
+{
+  $Gapp::TimeEntry::VERSION = '0.480';
+}
 
 use Moose;
 use MooseX::SemiAffordanceAccessor;
@@ -6,9 +9,9 @@ use MooseX::SemiAffordanceAccessor;
 use Gapp::Gtk2::DateEntry;
 
 extends 'Gapp::Entry';
-with 'Gapp::Meta::Widget::Native::Trait::FormField';
+with 'Gapp::Meta::Widget::Native::Role::FormField';
 
-has '+class' => (
+has '+gclass' => (
     default => 'Gapp::Gtk2::TimeEntry',
 );
 
@@ -17,9 +20,9 @@ sub BUILDARGS {
     my $class = shift;
     my %args = @_ == 1 && is_HashRef( $_[0] ) ? %{$_[0]} : @_;
     
-    if ( exists $args{value} ) {
-        $args{properties}{value} = $args{value};
-        delete $args{value};
+    
+    for my $att ( qw(value) ) {
+        $args{properties}{$att} = delete $args{$att} if exists $args{$att};
     }
 
     __PACKAGE__->SUPER::BUILDARGS( %args );
@@ -27,18 +30,18 @@ sub BUILDARGS {
 
 # returns the value of the widget
 sub get_field_value {
-    $_[0]->gtk_widget->get_value;
+    $_[0]->gobject->get_value;
 }
 
 sub set_field_value {
     my ( $self, $value ) = @_;
-    $self->gtk_widget->set_value( $value );
+    $self->gobject->set_value( $value );
 }
 
 sub _connect_changed_handler {
     my ( $self ) = @_;
 
-    $self->gtk_widget->signal_connect (
+    $self->gobject->signal_connect (
       'value-changed' => sub { $self->_widget_value_changed },
     );
 }
@@ -63,13 +66,11 @@ Gapp::TimeEntry - TimeEntry Widget
 
 =item +-- L<Gapp::Entry>
 
-=item ----+-- L<Gapp::TimeEntry>
+=item ....+-- L<Gapp::TimeEntry>
 
 =back
 
-=head1 DELEGATES TO GTK
-
-=head2 Attributes
+=head1 DELEGATED PROPERTIES
 
 =over 4
 
@@ -83,7 +84,7 @@ Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
 
 =head1 COPYRIGHT & LICENSE
 
-    Copyright (c) 2011 Jeffrey Ray Hallock.
+    Copyright (c) 2011-2012 Jeffrey Ray Hallock.
 
     This program is free software; you can redistribute it and/or
     modify it under the same terms as Perl itself.
