@@ -1,11 +1,15 @@
 package Gapp::ToggleButton;
+{
+  $Gapp::ToggleButton::VERSION = '0.480';
+}
 
 use Moose;
 use MooseX::SemiAffordanceAccessor;
 
 extends 'Gapp::Button';
+with 'Gapp::Meta::Widget::Native::Role::FormField';
 
-has '+class' => (
+has '+gclass' => (
     default => 'Gtk2::ToggleButton',
 );
 
@@ -15,6 +19,12 @@ has 'value' => (
     default => '1',
 );
 
+has 'off_value' => (
+    is => 'rw',
+    isa => 'Str',
+    default => '0',
+);
+
 
 sub BUILDARGS {
     my $class = shift;
@@ -29,7 +39,7 @@ sub BUILDARGS {
 
 sub get_field_value {
     my $self = shift;
-    my $state = $self->gtk_widget->get_active;
+    my $state = $self->gobject->get_active;
     if ( $state ) {
         return $self->value;
     }
@@ -42,10 +52,10 @@ sub get_field_value {
 sub set_field_value {
     my ( $self, $value ) = @_;
     if ( defined $value && $value eq $self->value ) {
-        $self->gtk_widget->set_active( 1 )
+        $self->gobject->set_active( 1 )
     }
     else {
-        $self->gtk_widget->set_active( 0 )
+        $self->gobject->set_active( 0 )
     }
 }
 
@@ -59,6 +69,14 @@ sub stash_to_widget {
     $self->set_field_value( $stash->fetch( $self->field ) );
 }
 
+sub _connect_changed_handler {
+    my ( $self ) = @_;
+
+    $self->gobject->signal_connect (
+      toggled => sub { $self->_widget_value_changed },
+    );
+}
+
 1;
 
 
@@ -113,7 +131,7 @@ Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
 
 =head1 COPYRIGHT & LICENSE
 
-    Copyright (c) 2011 Jeffrey Ray Hallock.
+    Copyright (c) 2011-2012 Jeffrey Ray Hallock.
 
     This program is free software; you can redistribute it and/or
     modify it under the same terms as Perl itself.
