@@ -1,12 +1,15 @@
 package Gapp::UIManager;
+{
+  $Gapp::UIManager::VERSION = '0.480';
+}
 
 use Moose;
 use MooseX::SemiAffordanceAccessor;
-extends 'Gapp::Widget';
+extends 'Gapp::Object';
 
 use Gapp::ActionGroup;
 
-has '+class' => (
+has '+gclass' => (
     default => 'Gtk2::UIManager',
 );
 
@@ -28,17 +31,17 @@ has 'action_args' => (
     default => sub { [ ] },
 );
 
-after _construct_gtk_widget => sub {
+after _construct_gobject => sub {
     my $self = shift;
-   $self->gtk_widget->add_ui_from_file( $_ ) for @{ $self->files };
-   $self->_apply_actions_to_gtk_widget;
+   $self->gobject->add_ui_from_file( $_ ) for @{ $self->files };
+   $self->_apply_actions_to_gobject;
 };
 
-sub _apply_actions_to_gtk_widget {
+sub _apply_actions_to_gobject {
     my ( $self ) = @_;
     
     my $group = Gapp::ActionGroup->new( actions => [@{$self->actions}], action_args => [@{$self->action_args}] );
-    $self->gtk_widget->insert_action_group( $group->gtk_widget, 0 );
+    $self->gobject->insert_action_group( $group->gobject, 0 );
 }
 
 1;
@@ -49,13 +52,13 @@ __END__
 
 =head1 NAME
 
-Gapp::UIManager - UIManager Widget
+Gapp::UIManager - UIManager object
 
 =head1 OBJECT HIERARCHY
 
 =over 4
 
-=item L<Gapp::Widget>
+=item L<Gapp::Object>
 
 =item +-- L<Gapp::UIManager>
 
@@ -97,7 +100,7 @@ Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
 
 =head1 COPYRIGHT & LICENSE
 
-    Copyright (c) 2011 Jeffrey Ray Hallock.
+    Copyright (c) 2011-2012 Jeffrey Ray Hallock.
 
     This program is free software; you can redistribute it and/or
     modify it under the same terms as Perl itself.
