@@ -1,9 +1,12 @@
 package Gapp::VBox;
+{
+  $Gapp::VBox::VERSION = '0.480';
+}
 
 use Moose;
 extends 'Gapp::Box';
 
-has '+class' => (
+has '+gclass' => (
     default => 'Gtk2::VBox',
 );
 
@@ -24,13 +27,15 @@ Gapp::VBox - VBox Widget
 
 =over 4
 
-=item L<Gapp::Widget>
+=item L<Gapp::Object>
 
-=item +-- L<Gapp::Container>
+=item +-- L<Gapp::Widget>
 
-=item ....+-- L<Gapp::Box>
+=item ....+-- L<Gapp::Container>
 
-=item ........+-- L<Gapp::VBox>
+=item ........+-- L<Gapp::Box>
+
+=item ............+-- L<Gapp::VBox>
 
 =back
 
@@ -40,7 +45,7 @@ Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
 
 =head1 COPYRIGHT & LICENSE
 
-    Copyright (c) 2011 Jeffrey Ray Hallock.
+    Copyright (c) 2011-2012 Jeffrey Ray Hallock.
 
     This program is free software; you can redistribute it and/or
     modify it under the same terms as Perl itself.
