@@ -1,11 +1,14 @@
 package Gapp::VButtonBox;
+{
+  $Gapp::VButtonBox::VERSION = '0.480';
+}
 
 use Moose;
 use MooseX::SemiAffordanceAccessor;
 
 extends 'Gapp::ButtonBox';
 
-has '+class' => (
+has '+gclass' => (
     default => 'Gtk2::VButtonBox',
 );
 
@@ -24,15 +27,17 @@ Gapp::VButtonBox - ButtonBox widget
 
 =over 4
 
-=item L<Gapp::Widget>
+=item L<Gapp::Object>
 
-=item +-- L<Gapp::Container>
+=item +-- L<Gapp::Widget>
 
-=item ....+-- L<Gapp::Box>
+=item ....+-- L<Gapp::Container>
 
-=item ........+-- L<Gapp::ButtonBox>
+=item ........+-- L<Gapp::Box>
 
-=item ............+-- L<Gapp::VButtonBox>
+=item ............+-- L<Gapp::ButtonBox>
+
+=item ................+-- L<Gapp::VButtonBox>
 
 =back
 
@@ -42,7 +47,7 @@ Jeffrey Ray Hallock E<lt>jeffrey.hallock at gmail dot comE<gt>
 
 =head1 COPYRIGHT & LICENSE
 
-    Copyright (c) 2011 Jeffrey Ray Hallock.
+    Copyright (c) 2011-2012 Jeffrey Ray Hallock.
 
     This program is free software; you can redistribute it and/or
     modify it under the same terms as Perl itself.
